@@ -1,26 +1,26 @@
-testthat::context("Testing predict.functions")
-
-### Datasets ####
-network <- mbnma.network(HF2PPITT)
-netgout <- mbnma.network(GoutSUA_2wkCFB)
-netalog <- mbnma.network(alog_pcfb)
-netpain <- mbnma.network(osteopain_2wkabs)
-netclass <- mbnma.network(osteopain_2wkabs)
-
-# Generate data without placebo
-noplac.df <- network$data.ab[network$data.ab$narm>2 & network$data.ab$agent!=1,]
-net.noplac <- mbnma.network(noplac.df)
-
-
-#### Models ####
-
+# testthat::context("Testing predict.functions")
+#
+# ### Datasets ####
+# network <- mbnma.network(HF2PPITT)
+# netgout <- mbnma.network(GoutSUA_2wkCFB)
+# netalog <- mbnma.network(alog_pcfb)
+# netpain <- mbnma.network(osteopain_2wkabs)
+# netclass <- mbnma.network(osteopain_2wkabs)
+#
+# # Generate data without placebo
+# noplac.df <- network$data.ab[network$data.ab$narm>2 & network$data.ab$agent!=1,]
+# net.noplac <- mbnma.network(noplac.df)
+#
+#
+# #### Models ####
+#
 # linear <- mbnma.run(netpain, fun="linear", n.iter=1000)
 #
 # emax <- mbnma.emax(network, emax="rel", ed50="rel", method="random", n.iter=1000)
 # emax.gout <- mbnma.emax(netgout, emax="rel", ed50="rel", method="random", n.iter=1000)
 #
-# emax.class <- mbnma.emax(netclass, emax="rel", ed50="random", method="common",
-#                          class.effect=list(emax="random"), n.iter=1000)
+# emax.class <- suppressWarnings(mbnma.emax(netclass, emax="rel", ed50="random", method="common",
+#                          class.effect=list(emax="random"), n.iter=1000))
 #
 # nonparam <- mbnma.run(network, fun="nonparam.up", n.iter=1000)
 #
@@ -51,39 +51,39 @@ net.noplac <- mbnma.network(noplac.df)
 #   #expect_equal(nrow(result$sd.mu), 600)
 #
 # })
-
-
-
-testthat::test_that("rescale.link functions correctly", {
-
-  x <- c(-5,1,0)
-
-  y <- rescale.link(x, direction="link", link="identity")
-  expect_identical(x,y)
-
-  y <- rescale.link(x, direction="natural", link="identity")
-  expect_identical(x,y)
-
-  expect_silent(rescale.link(x, direction="natural", link="logit"))
-  expect_warning(rescale.link(x, direction="link", link="logit"))
-
-  expect_warning(rescale.link(x, direction="link", link="probit"))
-  expect_silent(rescale.link(x, direction="natural", link="probit"))
-
-})
-
-
-
+#
+#
+#
+# testthat::test_that("rescale.link functions correctly", {
+#
+#   x <- c(-5,1,0)
+#
+#   y <- rescale.link(x, direction="link", link="identity")
+#   expect_identical(x,y)
+#
+#   y <- rescale.link(x, direction="natural", link="identity")
+#   expect_identical(x,y)
+#
+#   expect_silent(rescale.link(x, direction="natural", link="logit"))
+#   expect_warning(rescale.link(x, direction="link", link="logit"))
+#
+#   expect_warning(rescale.link(x, direction="link", link="probit"))
+#   expect_silent(rescale.link(x, direction="natural", link="probit"))
+#
+# })
+#
+#
+#
 # testthat::test_that("predict.mbnma functions correctly", {
 #   #ref.df <- network$data.ab[network$data.ab$agent==1,]
 #
 #   # Estimating E0
 #   ref.df <- netalog$data.ab[netalog$data.ab$agent==1,]
 #   pred <- predict(linear, E0 = ref.df)
-#   expect_identical(names(pred), c("predicts", "likelihood", "link"))
+#   expect_identical(names(pred), c("predicts", "likelihood", "link", "network"))
 #   expect_equal(linear$model.arg$likelihood, pred$likelihood)
 #   expect_equal(linear$model.arg$link, pred$link)
-#   expect_identical(names(pred$predicts), linear$agents)
+#   expect_identical(names(pred$predicts), linear$network$agents)
 #   expect_silent(as.numeric(names(pred$predicts[[4]])))
 #   expect_equal(class(pred$predicts[[4]][[4]]), "matrix")
 #   expect_equal(nrow(pred$predicts[[4]][[4]]), linear$BUGSoutput$n.sims)
@@ -114,7 +114,7 @@ testthat::test_that("rescale.link functions correctly", {
 #     max.doses[[length(max.doses)+1]] <- 1
 #   }
 #   pred <- predict(emax, E0=0.1, max.doses = max.doses)
-#   expect_identical(names(pred$predicts), emax$agents)
+#   expect_identical(names(pred$predicts), emax$network$agents)
 #   expect_equal(all(pred$predicts[[2]][[2]][1] > 0), TRUE)
 #   expect_error(print(pred), NA)
 #   expect_equal(class(summary(pred)), "data.frame")
@@ -123,7 +123,7 @@ testthat::test_that("rescale.link functions correctly", {
 #   expect_silent(predict(emax, E0=0.1, max.doses = max.doses))
 #
 #   max.doses[[9]] <- 1
-#   expect_error(predict(linear, E0=0.1, max.doses = max.doses))
+#   expect_error(predict(emax, E0=0.1, max.doses = max.doses))
 #
 #   max.doses <- list("eletriptan"=3, "rizatriptan"=2)
 #   pred <- predict(emax, E0=0.1, max.doses = max.doses, n.doses = 10)
@@ -174,12 +174,19 @@ testthat::test_that("rescale.link functions correctly", {
 #     max.doses[[length(max.doses)+1]] <- 1
 #   }
 #   pred <- predict(emax.noplac, E0=0.1, max.doses = max.doses)
-#   expect_identical(names(pred$predicts), emax.noplac$agents)
+#   expect_identical(names(pred$predicts), emax.noplac$network$agents)
 #   expect_error(print(pred), NA)
 #   expect_equal(class(summary(pred)), "data.frame")
 #
+#
+#   # Multiple dose-response functions
+#   multifun <- mbnma.run(network, fun=c(rep("exponential", 3), rep("linear",2), rep("emax",3)))
+#   expect_silent(predict(multifun, E0=0.2))
+#   pred <- predict(multifun, E0=0.2, exact.doses = list("eletriptan"=seq(0,2,0.1), "rizatriptan"=seq(0,2,0.1)))
+#   expect_identical(names(pred$predicts), c("eletriptan", "rizatriptan"))
+#
 # })
-
-
-
-
+#
+#
+#
+#
